summaryrefslogtreecommitdiff
path: root/framework/source/dispatch/dispatchprovider.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/source/dispatch/dispatchprovider.cxx')
-rw-r--r--framework/source/dispatch/dispatchprovider.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/source/dispatch/dispatchprovider.cxx b/framework/source/dispatch/dispatchprovider.cxx
index 868a3b382bdb..678b4885601a 100644
--- a/framework/source/dispatch/dispatchprovider.cxx
+++ b/framework/source/dispatch/dispatchprovider.cxx
@@ -65,7 +65,7 @@ DEFINE_XTYPEPROVIDER_2( DispatchProvider ,
/**
@short standard ctor/dtor
- @descr These initialize a new instance of tihs class with needed informations for work.
+ @descr These initialize a new instance of tihs class with needed information for work.
We hold a weakreference to our owner frame which start dispatches at us.
We can't use a normal reference because he hold a reference of us too ...
nobody can die so ...!
@@ -529,7 +529,7 @@ css::uno::Reference< css::frame::XDispatch > DispatchProvider::implts_searchProt
{
try
{
// but do it only, if all context informations are OK
css::uno::Sequence< css::uno::Any > lContext(1);
lContext[0] <<= xOwner;
xInit->initialize(lContext);
@@ -529,7 +529,7 @@ css::uno::Reference< css::frame::XDispatch > DispatchProvider::implts_searchProt
try
{
- // but do it only, if all context informations are OK
+ // but do it only, if all context information are OK
css::uno::Sequence< css::uno::Any > lContext(1);
lContext[0] <<= xOwner;